<div class="tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content">
      <div id="{{ tile_id }}-chart" class="chart cumulative-flow-chart chart-only"> </div>

      <div class="plot-labels">
          <h2 id="{{ tile_id }}-title" class="labels-title"></h2>
          <!--
          js appends labels dynamically here
          -->
      </div>
    </div>
</div>

