<div class="tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content">
        <span class="text-container"></span>
    </div>
</div>

