#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals


VERSION = (1, 4, 3)
__version__ = '.'.join(str(num) for num in VERSION)
