<div class="tile norm-chart-tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3 >{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{ tile_id }}-title" class="result big-result"></h2>
        <h3 id="{{tile_id }}-description" class="result label"> </h3>
        <div id="{{ tile_id }}-chart" class="chart round-legend"> </div>
    </div>
</div>
