<div class="tile fancy-listing" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content overflow-proof">
        <div id="{{tile_id}}-fancy-listing-item" class="fancy-listing-item">
            <div class="float-wrapper">
              <div class="fancy-listing-label centerbox">
                <span class="fancy-listing-label-inside"></span>
              </div>
            </div>
            <div class="fancy-listing-def">
                <h3 class="fancy-listing-term"></h3>
                <p class="fancy-listing-desc"></p>
            </div>
        </div>
    </div>
</div>

