<div class="tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{tile_id}}-title" class="result big-result"></h2>
        <h3 id="{{tile_id}}-subtitle" class="result label" ></h3>
        <div id="{{ tile_id }}-chart" class="chart bar-chart" > </div>
    </div>
</div>
