<div class="tile highlighter-tile simple-percentage-tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{ tile_id }}-title" class="result big-result fixed-height"></h2>
        <h3 id="{{ tile_id }}-subtitle" class="result subtitle label fixed-height"></h3>
        <div class="result big-value-container">
            <span id="{{ tile_id }}-big_value"></span>
        </div>
        <div class="result-row highlight-footer">
            <div class="result-col with-right-border">
                <div id="{{ tile_id }}-left_label" class="result label"></div>
                <div id="{{ tile_id }}-left_value" class="result medium-result"><span></span></div>
            </div>
            <div class="result-col">
                <div id="{{ tile_id }}-right_label" class="result label"></div>
                <div id="{{ tile_id }}-right_value" class="result medium-result"><span></span></div>
            </div>
        </div>
    </div>
</div>
