<div class="tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content tile-empty">
        <h2>This is an empty tile.</h2>
    </div>
</div>
