<div class="tile highlighter-tile big_value_tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3 >{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{ tile_id }}-title" class="result big-result fixed-height"></h2>
        <h3 id="{{ tile_id }}-description" class="result label fixed-height"
        ></h3>
        <div class="result big-value-container">
          <span id="{{ tile_id }}-big-value" class="big-value"></span>
        </div>
        <div class="result-row highlight-footer">
            <div class="result-half-col">
              <div class="result">
                <span id="{{ tile_id }}-upper-left-label" class="label"></span>
                <span id="{{ tile_id }}-upper-left-value"></span>
              </div>
              <div class="result">
                <span id="{{ tile_id}}-lower-left-label" class="label"></span>
                <span id="{{ tile_id}}-lower-left-value"></span>
              </div>
            </div>
            <div class="result-half-col">
              <div class="result">
                <span id="{{ tile_id }}-upper-right-label" class="label"></span>
                <span id="{{ tile_id }}-upper-right-value"></span>
              </div>
              <div class="result">
                <span id="{{ tile_id }}-lower-right-label" class="label"></span>
                <span id="{{ tile_id }}-lower-right-value"></span>
              </div>
            </div>
        </div>
    </div>
</div>
