<div class="tile advanced-plot-tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3 >{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{ tile_id }}-title" class="title"></h2>
        <div
            id="{{ tile_id }}-description"
            class="result label description"
        ></div>

        <div id="{{ tile_id }}-chart" class="chart advanced-plot"> </div>
    </div>
</div>
