<div class="tile highlighter-tile just-value-tile" id="{{ tile_id }}">
    <div class="tile-header">
        <h3>{{ title }}</h3>
    </div>
    <div class="tile-content">
        <h2 id="{{ tile_id }}-title" class="result big-result fixed-height"></h2>
        <h3
            id="{{ tile_id }}-description"
            class="result label fixed-height"
        ></h3>
        <div class="result big-result highlighted-result just-value-div" >
            <span id="{{ tile_id }}-just-value" class="just-value" > </span>
        </div>

    </div>
</div>
